IsolateActionGroupResult class

Constructors

IsolateActionGroupResult({required bool passes, required List exceptions})

Properties

exceptions List
final
hashCode int
The hash code for this object.
no setterinherited
passes bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited