Database class abstract

Constructors

Database()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

database ↔ Database
getter/setter pair
tables List<TableSchema>
latefinal

Static Methods

addTable(TableSchema tableSchema) → void
addTables(List<TableSchema> tables) → void
clear() Future<void>
configure({required int version, required String databaseName, List<TableSchema> tables = const [], bool logEnabled = true}) → void
initialize() Future<void>