Join class

Constructors

Join({required JoinType type, required JoinDirection direction, String? table, String? alias, String? column1, String? column2, Query? subQuery, JoinClauseInner? innerClause})

Properties

alias String?
getter/setter pair
column1 String?
getter/setter pair
column2 String?
getter/setter pair
direction JoinDirection
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
innerClause JoinClauseInner?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subQuery Query?
getter/setter pair
table String?
getter/setter pair
type JoinType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSql() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited