JoinClause class

Constructors

JoinClause()

Properties

hashCode int
The hash code for this object.
no setterinherited
joins List<Join>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

join(String table, String column1, String column2) JoinClause
joinClause(String table, void callback(JoinClauseInner join)) JoinClause
joinSub(Query query, String alias, String column1, String column2) JoinClause
leftJoin(String table, String column1, String column2) JoinClause
leftJoinClause(String table, void callback(JoinClauseInner join)) JoinClause
leftJoinSub(Query query, String alias, String column1, String column2) JoinClause
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSql() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited