Model<T> class abstract

Constructors

Model()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → T
delete() Future<void>
getFactory() ModelFactory<T>
getQuery() Query<T>
getSchema() TableSchema
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save({Batch? batch, Transaction? transaction}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited