TableSchema class

Constructors

TableSchema({required List<ColumnSchema> columns, required String name, required String key, bool synchronize = true})

Properties

columns List<ColumnSchema>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
key String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
synchronize bool
getter/setter pair

Methods

create() Future<void>
drop() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
truncate() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited