Where class

Constructors

Where({QueryCondition? condition, WhereType? type, String? column, String? comparator, dynamic value, void callback(WhereClause query)?})

Properties

callback ↔ void Function(WhereClause query)?
getter/setter pair
column String?
getter/setter pair
comparator String?
getter/setter pair
condition QueryCondition?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type WhereType?
getter/setter pair
value ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSql() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited