WhereClause class

Constructors

WhereClause()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wheres List<Where>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orWhere(String column, String comparator, dynamic value) WhereClause
orWhereClause(void callback(WhereClause query)) WhereClause
orWhereIn(String column, List value) WhereClause
toSql() String
toString() String
A string representation of this object.
inherited
where(String column, String comparator, dynamic value) WhereClause
whereClause(void callback(WhereClause query)) WhereClause
whereIn(String column, List value) WhereClause

Operators

operator ==(Object other) bool
The equality operator.
inherited