ListPicker<T> class

Inheritance

Constructors

ListPicker({Key? key, required List<ListPickerOption> options, required void onSave(List<T> result)?, void onCancel()?, List<T> selected = const [], required ListPickerMode mode})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mode ListPickerMode
final
onCancel → void Function()?
final
onSave → void Function(List<T> result)?
final
options List<ListPickerOption>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected List<T>
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _ListPickerState<T>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

multiple<T>(BuildContext context, {required List<ListPickerOption> options, void onSave(List<T> result)?, void onCancel()?, List<T> selected = const []}) Future<List<T>>
single<T>(BuildContext context, {required List<ListPickerOption> options, void onSave(T? result)?, void onCancel()?, T? selected}) Future<T?>