Nav class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isPopping bool
getter/setter pair

Static Methods

maybePop<T>(BuildContext context, [T? result, bool delayed = true]) Future<bool>
pop<T>(BuildContext context, [T? result]) → void
push<T>(BuildContext context, Widget page, {String? name, PageRouteType transitionType = PageRouteType.material}) Future<T?>
pushAndRemoveUntil<T>(BuildContext context, Widget page, {String? name, bool delayed = true, PageRouteType transitionType = PageRouteType.material}) Future<T?>