ActionScheduler class abstract

Constructors

ActionScheduler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

actions List<_ScheduledAction>
final
logs List<_ScheduledActionLog>
final

Static Methods

initialize() Future<void>
receiveHeartbeat() Future<void>
registerTask({required String id, required Action action, required Duration interval}) → void
save() Future<void>