Server class abstract

Static class to connect the app with the server.

Constructors

Server()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

host String?
getter/setter pair
url String?
getter/setter pair

Static Methods

get(String endpoint, {Map<String, dynamic>? params, Map<String, String>? headers, Function? callback, bool log = true}) Future
Sends a GET request.
initialize() Future<void>
post<T>(String endpoint, {Map<String, dynamic>? params, Map<String, String>? headers, Object? body, Function? callback}) Future<T>
Sends a POST request.
save() Future<void>