IsolateActionGroup class
Constructors
-
IsolateActionGroup({required int concurrents, required List<
IsolateAction> jobs, bool stopOnError = true})
Properties
- concurrents → int
-
final
- exceptions → List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
jobs
→ List<
IsolateAction> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopOnError → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onJobFinished(
IsolateAction job) → void -
processQueue(
) → void -
run(
) → Future< IsolateActionGroupResult> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited