JoinClauseInner class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on(
String column1, String column2) → JoinClauseInner -
orWhere(
String column, String comparator, dynamic value) → JoinClauseInner -
orWhereClause(
void callback(WhereClause query)) → JoinClauseInner -
orWhereIn(
String column, List value) → JoinClauseInner -
toSql(
) → String -
toString(
) → String -
A string representation of this object.
inherited
-
where(
String column, String comparator, dynamic value) → JoinClauseInner -
whereClause(
void callback(WhereClause query)) → JoinClauseInner -
whereIn(
String column, List value) → JoinClauseInner
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited