ServerResponse class
Class to send http requests to the server. Every request sent to the server should be through this class.
Constructors
- ServerResponse(Response raw)
Properties
- body → String
-
no setter
- fails → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpCode → int
-
no setter
-
json
→ Map<
String, dynamic> -
no setter
- passes → bool
-
no setter
- raw → Response
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited